##  Filling Fact Sheet Data from Recommendations
To help you improve the completeness and quality of your fact sheet data, SAP LeanIX provides AI-powered recommendations. You can find all recommendations in the Recommendations tab on the fact sheet, making it easy to review and manage them in one place.
Currently, you can act on the following recommendations:
  * Fact sheet descriptions: The content and context of the fact sheet are analyzed to generate a concise description for fact sheets.
  * Business capability relations for applications: The application's name and description are semantically compared with those of business capabilities in your workspace to identify and suggest the most relevant matches. Currently, this is available for the application fact sheets and the AI agent subtype.
These business capability recommendations are also shown while you are linking business capabilities to applications in the fact sheet. To learn more, see [Business Capability Recommendations for Applications While Adding Relations](https://help.sap.com/docs/leanix/ea/adding-and-editing-data-in-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD#loio275857617a44101499a0c3d00c27319a__business_capability_recommendations_for_applications_while_adding_relations).
**Remember**
Business capability recommendations appear only after the application description has been completed.


You can review the recommendation and click Accept to apply the suggested updates to your fact sheet. You can revert the updates by clicking on the undo icon before the Accept button.
